@@ -19,6 +19,7 @@ class SummarizationMiddleware(_SummarizationMiddleware):
         token_counter: Function to count tokens in messages.
         summary_prompt: Prompt template for generating summaries.
         summary_prefix: Prefix added to system message when including summary.
+
     Examples:
         ```python
         from langchain_dev_utils.agents.middleware import SummarizationMiddleware
@@ -36,17 +37,6 @@ class SummarizationMiddleware(_SummarizationMiddleware):
         summary_prompt: Optional[str] = None,
         summary_prefix: Optional[str] = None,
     ) -> None:
-        """Initialize the summarization middleware.
-
-        Args:
-            model: The language model to use for generating summaries. Only string identifiers are supported.
-            max_tokens_before_summary: Token threshold to trigger summarization.
-                If `None`, summarization is disabled.
-            messages_to_keep: Number of recent messages to preserve after summarization.
-            token_counter: Function to count tokens in messages.
-            summary_prompt: Prompt template for generating summaries.
-            summary_prefix: Prefix added to system message when including summary.
-        """
         chat_model = load_chat_model(model)
 
         middleware_kwargs = {}
